Animation

Struct Animation 

pub struct Animation {
    pub _file_id: String,
    pub _thumb: Option<PhotoSize>,
    pub _file_name: Option<String>,
    pub _mime_type: Option<String>,
    pub _file_size: Option<i32>,
}
You can provide an animation for your game so that it looks stylish in chats (check out Lumberjack for an example). This object represents an animation file to be displayed in the message containing a game.

Fields

_file_id: String

Unique file identifier

_thumb: Option<PhotoSize>

Optional. Animation thumbnail as defined by sender

_file_name: Option<String>

Optional. Original animation filename as defined by sender

_mime_type: Option<String>

Optional. MIME type of the file as defined by sender

_file_size: Option<i32>

Optional. File size