Audio

Struct Audio 

pub struct Audio {
    pub _file_id: String,
    pub _duration: i32,
    pub _performer: Option<String>,
    pub _title: Option<String>,
    pub _mime_type: Option<String>,
    pub _file_size: Option<i32>,
}
This object represents an audio file to be treated as music by the Telegram clients.

Fields

_file_id: String

Unique identifier for this file

_duration: i32

Duration of the audio in seconds as defined by sender

_performer: Option<String>

Optional. Performer of the audio as defined by sender or by audio tags

_title: Option<String>

Optional. Title of the audio as defined by sender or by audio tags

_mime_type: Option<String>

Optional. MIME type of the file as defined by sender

_file_size: Option<i32>

Optional. File size