CallbackQuery

Struct CallbackQuery 

pub struct CallbackQuery {
    pub _id: String,
    pub _from: User,
    pub _message: Option<Message>,
    pub _inline_message_id: Option<String>,
    pub _chat_instance: String,
    pub _data: Option<String>,
    pub _game_short_name: Option<String>,
}
This object represents an incoming callback query from a callback button in an inline keyboard. If the button that originated the query was attached to a message sent by the bot, the field message will be present. If the button was attached to a message sent via the bot (in inline mode), the field inline_message_id will be present. Exactly one of the fields data or game_short_name will be present.

Fields

_id: String

Unique identifier for this query

_from: User

Sender

_message: Option<Message>

Optional. Message with the callback button that originated the query. Note that message content and message date will not be available if the message is too old

_inline_message_id: Option<String>

Optional. Identifier of the message sent via the bot in inline mode, that originated the query.

_chat_instance: String

Global identifier, uniquely corresponding to the chat to which the message with the callback button was sent. Useful for high scores in games.

_data: Option<String>

Optional. Data associated with the callback button. Be aware that a bad client can send arbitrary data in this field.

_game_short_name: Option<String>

Optional. Short name of a Game to be returned, serves as the unique identifier for the game