pub struct Document {
pub _file_id: String,
pub _thumb: Option<PhotoSize>,
pub _file_name: Option<String>,
pub _mime_type: Option<String>,
pub _file_size: Option<i32>,
}Expand description
This object represents a general file (as opposed to photos, voice messages and audio files).
Fields
_file_id: StringUnique file identifier
_thumb: Option<PhotoSize>Optional. Document thumbnail as defined by sender
_file_name: Option<String>Optional. Original filename as defined by sender
_mime_type: Option<String>Optional. MIME type of the file as defined by sender
_file_size: Option<i32>Optional. File size