pub struct Invoice {
pub _title: String,
pub _description: String,
pub _start_parameter: String,
pub _currency: String,
pub _total_amount: i32,
}Expand description
This object contains basic information about an invoice.
Fields
_title: StringProduct name
_description: StringProduct description
_start_parameter: StringUnique bot deep-linking parameter that can be used to generate this invoice
_currency: StringThree-letter ISO 4217 currency code
_total_amount: i32Total price in the smallest units of the currency (integer, not float/double). For example, for a price of US$ 1.45 pass amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).