KeyboardButton

Struct KeyboardButton 

pub struct KeyboardButton {
    pub _text: String,
    pub _request_contact: Option<bool>,
    pub _request_location: Option<bool>,
}
This object represents one button of the reply keyboard. For simple text buttons String can be used instead of this object to specify text of the button. Optional fields are mutually exclusive.

Fields

_text: String

Text of the button. If none of the optional fields are used, it will be sent to the bot as a message when the button is pressed

_request_contact: Option<bool>

Optional. If True, the user’s phone number will be sent as a contact when the button is pressed. Available in private chats only

_request_location: Option<bool>

Optional. If True, the user’s current location will be sent when the button is pressed. Available in private chats only