MaskPosition

Struct MaskPosition 

pub struct MaskPosition {
    pub _point: String,
    pub _x_shift: f32,
    pub _y_shift: f32,
    pub _scale: f32,
}
This object describes the position on faces where a mask should be placed by default.

Fields

_point: String

The part of the face relative to which the mask should be placed. One of “forehead”, “eyes”, “mouth”, or “chin”.

_x_shift: f32

Shift by X-axis measured in widths of the mask scaled to the face size, from left to right. For example, choosing -1.0 will place mask just to the left of the default mask position.

_y_shift: f32

Shift by Y-axis measured in heights of the mask scaled to the face size, from top to bottom. For example, 1.0 will place the mask just below the default mask position.

_scale: f32

Mask scaling coefficient. For example, 2.0 means double size.