MessageEntity

Struct MessageEntity 

pub struct MessageEntity {
    pub _type: String,
    pub _offset: i32,
    pub _length: i32,
    pub _url: Option<String>,
    pub _user: Option<User>,
}
This object represents one special entity in a text message. For example, hashtags, usernames, URLs, etc.

Fields

_type: String

Type of the entity. Can be mention (@username), hashtag, bot_command, url, email, bold (bold text), italic (italic text), code (monowidth string), pre (monowidth block), text_link (for clickable text URLs), text_mention (for users without usernames)

_offset: i32

Offset in UTF-16 code units to the start of the entity

_length: i32

Length of the entity in UTF-16 code units

_url: Option<String>

Optional. For “text_link” only, url that will be opened after user taps on the text

_user: Option<User>

Optional. For “text_mention” only, the mentioned user