pub struct Video {
pub _file_id: String,
pub _width: i32,
pub _height: i32,
pub _duration: i32,
pub _thumb: Option<PhotoSize>,
pub _mime_type: Option<String>,
pub _file_size: Option<i32>,
}Expand description
This object represents a video file.
Fields
_file_id: StringUnique identifier for this file
_width: i32Video width as defined by sender
_height: i32Video height as defined by sender
_duration: i32Duration of the video in seconds as defined by sender
_thumb: Option<PhotoSize>Optional. Video thumbnail
_mime_type: Option<String>Optional. Mime type of a file as defined by sender
_file_size: Option<i32>Optional. File size