pub struct Sticker {
pub _file_id: String,
pub _width: i32,
pub _height: i32,
pub _thumb: Option<PhotoSize>,
pub _emoji: Option<String>,
pub _set_name: Option<String>,
pub _mask_position: Option<MaskPosition>,
pub _file_size: Option<i32>,
}Expand description
This object represents a sticker.
Fields
_file_id: StringUnique identifier for this file
_width: i32Sticker width
_height: i32Sticker height
_thumb: Option<PhotoSize>Optional. Sticker thumbnail in the .webp or .jpg format
_emoji: Option<String>Optional. Emoji associated with the sticker
_set_name: Option<String>Optional. Name of the sticker set to which the sticker belongs
_mask_position: Option<MaskPosition>Optional. For mask stickers, the position where the mask should be placed
_file_size: Option<i32>Optional. File size